bump
====

Increase your package version number in the configuration file.

Modifications
-------------

This tool will overwrite your package config file. You'll still have to call
'rg' to regenerate your files with the new version.

Quick tutorial
--------------

Just call the tool at the root of your package with the part of the version number
you want to increase::

    (dvlpt)$ pmg bump minor

